Requirements
============

  * Django 1.8 or later


Documentation
=============

To build the documentation, go into the docs directory and type:

    make html

The documentation will be built with an index of docs/_build/index.html
